// src/backend/schedulable.hh - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef SCHEDULABLE_HH
#define SCHEDULABLE_HH 1

#include "config.h"
#include "glibmm/ustring.h"

namespace sgpem
{
  class Schedulable;

  /** \brief An entity that can use the processor
   *
   *  This abstract class describes an entity that can use the 
   *  processor. It describes the parameters that don't change 
   *  during a simulation.
   *  All subclasses are ... (FIXME: teach Luca and Marco what's 
   *  the Italian language for, damn them! -- they must have 
   *  *smoked* mushrooms! :-) ) */
  class DLLEXPORT Schedulable 
  {
  public:
	Schedulable(const Glib::ustring& name, const unsigned int& arrival, const unsigned int& total, const int& priority);
    virtual ~Schedulable() = 0;
    
    virtual unsigned int 	getArrivalTime()  const;
    unsigned int 			getTotalCPUTime() const;
    int 					getPriority() const;
	Glib::ustring 			getName() const;
	virtual Glib::ustring	getType() const =0;
	
  private:
    Glib::ustring _name;
	unsigned int _arrival_time;
    unsigned int _total_time;
    int          _priority;
	
  };
    
}

#endif
